@@ -47,21 +47,16 @@ mco plugin package [options] <directory>
            :arguments => ["--pluginpath PATH"],
            :type => String
 
-    option :mccommon,
-           :description => "Set the mcollective common package that the plugin depends on",
-           :arguments => ["--mc-common-pkg PACKAGE"],
+    option :mcname,
+           :description => "MCollective type (mcollective, pe-mcollective) that the packages depend on",
+           :arguments => ["--mcname NAME"],
            :type => String
 
-    option :mcserver,
-           :description => "Set the mcollective server package that the plugin depends on",
-           :arguments => ["--mc-server-pkg PACKAGE"],
+    option :mcversion,
+           :description => "Version of MCollective that the packages depend on",
+           :arguments => "--mcversion MCVERSION",
            :type => String
 
-    option :mcclient,
-           :description => "Set the mcollective client package that the plugin depends on",
-           :arguments => ["--mc-client-pkg PACKAGE"],
-           :type =>String
-
     option :dependency,
            :description => "Adds a dependency to the plugin",
            :arguments => ["--dependency DEPENDENCIES"],
@@ -130,7 +125,7 @@ mco plugin package [options] <directory>
         configuration[:target] = ARGV.delete_at(0) || "."
 
         if configuration[:action] == "generate"
-          unless ARGV[0].match(/(actions|outputs)=(.+)/i)
+          unless ARGV[0] && ARGV[0].match(/(actions|outputs)=(.+)/i)
             unless configuration[:pluginname]
               configuration[:pluginname] = ARGV.delete_at(0)
             else
@@ -158,6 +153,8 @@ mco plugin package [options] <directory>
 
     # Generate a plugin skeleton
     def generate_command
+      raise "undefined plugin type. cannot generate plugin. valid types are 'agent' and 'data'" if configuration["target"] == '.'
+
       unless configuration[:pluginname]
         puts "No plugin name specified. Using 'new_plugin'"
         configuration[:pluginname] = "new_plugin"
@@ -190,26 +187,31 @@ mco plugin package [options] <directory>
       plugin = prepare_plugin
       (configuration[:pluginpath] = configuration[:pluginpath] + "/") if (configuration[:pluginpath] && !configuration[:pluginpath].match(/^.*\/$/))
       packager = PluginPackager["#{configuration[:format].capitalize}Packager"]
-      packager.new(plugin, configuration[:pluginpath], configuration[:sign], configuration[:verbose]).create_packages
+      packager.new(plugin, configuration[:pluginpath], configuration[:sign], options[:verbose]).create_packages
+    end
+
+    # Agents are just called 'agent' but newer plugin types are
+    # called plugin_plugintype for example facter_facts etc so
+    # this will first try the old way then the new way.
+    def load_plugin_ddl(plugin, type)
+      [plugin, "#{plugin}_#{type}"].each do |p|
+        ddl = DDL.new(p, type, false)
+        if ddl.findddlfile(p, type)
+          ddl.loadddlfile
+          return ddl
+        end
+      end
+
+      return nil
     end
 
     # Show application list and plugin help
     def doc_command
-      known_plugin_types = [["Agents", :agent], ["Data Queries", :data], ["Discovery Methods", :discovery]]
+      known_plugin_types = [["Agents", :agent], ["Aggregate", :aggregate], ["Data Queries", :data], ["Discovery Methods", :discovery], ["Validator Plugins", :validator]]
 
       if configuration.include?(:target) && configuration[:target] != "."
         if configuration[:target] =~ /^(.+?)\/(.+)$/
-          plugin_type = $1.to_sym
-          plugin_name = $2
-
-          # Agents are just called 'agent' but newer plugin types are
-          # called plugin_plugintype for example facter_facts etc so
-          # this will first try the old way then the new way.
-          begin
-            ddl = DDL.new(plugin_name, plugin_type)
-          rescue
-            ddl = DDL.new("#{plugin_name}_#{plugin_type}", plugin_type)
-          end
+          ddl = load_plugin_ddl($2.to_sym, $1)
         else
           found_plugin_type = nil
 
@@ -223,30 +225,45 @@ mco plugin package [options] <directory>
             end
           end
 
-          abort "Could not find a plugin named %s in any supported plugin type" % plugin_type[1] unless found_plugin_type
-          begin
-            ddl = DDL.new(configuration[:target], found_plugin_type)
-          rescue
-            ddl = DDL.new("#{configuration[:target]}_#{found_plugin_type}", found_plugin_type)
-          end
+          abort "Could not find a plugin named '%s' in any supported plugin type" % configuration[:target] unless found_plugin_type
+          ddl = load_plugin_ddl(configuration[:target], found_plugin_type)
+        end
+
+        if ddl
+          puts ddl.help(configuration[:rpctemplate])
+        else
+          abort "Could not find a '%s' plugin named '%s'" % configuration[:target].split('/')
         end
 
-        puts ddl.help(configuration[:rpctemplate])
       else
         puts "Please specify a plugin. Available plugins are:"
         puts
 
+        load_errors = []
+
         known_plugin_types.each do |plugin_type|
           puts "%s:" % plugin_type[0]
 
           PluginManager.find(plugin_type[1], "ddl").each do |ddl|
-            help = DDL.new(ddl, plugin_type[1])
-            pluginname = ddl.gsub(/_#{plugin_type[1]}$/, "")
-            puts "  %-15s %s" % [pluginname, help.meta[:description]]
+            begin
+              help = DDL.new(ddl, plugin_type[1])
+              pluginname = ddl.gsub(/_#{plugin_type[1]}$/, "")
+              puts "  %-25s %s" % [pluginname, help.meta[:description]]
+            rescue => e
+              load_errors << [plugin_type[1], ddl, e]
+            end
           end
 
           puts
         end
+
+        unless load_errors.empty?
+          puts "Plugin Load Errors:"
+
+          load_errors.each do |e|
+            puts "  %-25s %s" % ["#{e[0]}/#{e[1]}", Util.colorize(:yellow, e[2])]
+          end
+        end
       end
     end
 
@@ -257,14 +274,13 @@ mco plugin package [options] <directory>
         PluginPackager.load_packagers
         plugin_class = PluginPackager[configuration[:plugintype]]
         configuration[:dependency] = configuration[:dependency][0].split(" ") if configuration[:dependency] && configuration[:dependency].size == 1
-        mcodependency = {:server => configuration[:mcserver],
-                         :client => configuration[:mcclient],
-                         :common => configuration[:mccommon]}
+        configuration[:dependency].map!{|dep| {:name => dep, :version => nil}} if configuration[:dependency]
+        mcdependency = {:mcname => configuration[:mcname], :mcversion => configuration[:mcversion]}
 
         plugin_class.new(configuration[:target], configuration[:pluginname],
                          configuration[:vendor], configuration[:preinstall],
                          configuration[:postinstall], configuration[:iteration],
-                         configuration[:dependency], mcodependency , plugintype)
+                         configuration[:dependency], mcdependency , plugintype)
     end
 
     def directory_for_type(type)
@@ -289,14 +305,13 @@ mco plugin package [options] <directory>
     # To keep it simple we limit it to one type per target directory.
     def identify_plugin
       plugintype = Dir.glob(File.join(configuration[:target], "*")).select do |file|
-        File.directory?(file) && file.match(/(connector|facts|registration|security|audit|pluginpackager|data|discovery)/)
+        File.directory?(file) && file.match(/(connector|facts|registration|security|audit|pluginpackager|data|discovery|validator)/)
       end
 
       raise RuntimeError, "more than one plugin type detected in directory" if plugintype.size > 1
       raise RuntimeError, "no plugins detected in directory" if plugintype.size < 1
 
-      stripdir = configuration[:target] == "." ? "" : configuration[:target]
-      plugintype.first.gsub(/\.|\/|#{stripdir}/, "")
+      File.basename(plugintype[0])
     end
 
     # Load preset metadata values from config if they are present
